==> owncloud-8.1.0p2.tgz: owncloud/apps/encryption/l10n/ko.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "잊어버린 복구 키 암호 복구",
    "Please repeat the recovery key password" : "복구 키 암호를 다시 입력하십시오",
    "Repeated recovery key password does not match the provided recovery key password" : "입력한 복구 키 암호가 서로 다릅니다",
    "Recovery key successfully enabled" : "복구 키가 성공적으로 활성화되었습니다",
    "Could not enable recovery key. Please check your recovery key password!" : "복구 키를 활성화 할 수 없습니다. 복구 키의 암호를 확인해 주십시오!",
    "Recovery key successfully disabled" : "복구 키가 성공적으로 비활성화 되었습니다",
    "Could not disable recovery key. Please check your recovery key password!" : "복구 키를 비활성화 할 수 없습니다. 복구 키의 암호를 확인해 주십시오!",
    "Missing parameters" : "인자 부족함",
    "Please provide the old recovery password" : "이전 복구 암호를 입력하십시오",
    "Please provide a new recovery password" : "새 복구 암호를 입력하십시오",
    "Please repeat the new recovery password" : "새 복구 암호를 다시 입력하십시오",
    "Password successfully changed." : "암호가 성공적으로 변경되었습니다",
    "Could not change the password. Maybe the old password was not correct." : "암호를 변경할 수 없습니다. 예전 암호가 정확하지 않은 것 같습니다.",
    "Recovery Key disabled" : "복구 키가 비활성화됨",
    "Recovery Key enabled" : "복구 키가 활성화됨",
    "Could not enable the recovery key, please try again or contact your administrator" : "복구 키를 활성화할 수 없습니다. 다시 시도하거나 관리자에게 연락하십시오",
    "Could not update the private key password." : "개인 키 암호를 업데이트할 수 없습니다",
    "The old password was not correct, please try again." : "이전 암호가 잘못되었습니다. 다시 시도하십시오.",
    "The current log-in password was not correct, please try again." : "현재 로그인 암호가 잘못되었습니다. 다시 시도하십시오.",
    "Private key password successfully updated." : "개인 키 암호가 성공적으로 업데이트 되었습니다.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "암호화 앱의 개인 키가 잘못되었습니다. 암호화된 파일에 다시 접근하려면 개인 설정에서 개인 키 암호를 업데이트해야 합니다.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "암호화 앱이 활성화되어 있지만 키가 초기화되지 않았습니다. 로그아웃한 후 다시 로그인하십시오",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "이 파일을 복호화할 수 없습니다. 공유된 파일일 수도 있습니다. 파일 소유자에게 공유를 다시 요청하십시오.",
    "Enable recovery key" : "복구 키 활성화",
    "Disable recovery key" : "복구 키 비활성화",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "복구 키는 파일을 암호화하는 추가 키입니다. 사용자가 암호를 잊었을 때 복구할 수 있도록 해 줍니다.",
    "Recovery key password" : "복구 키 암호",
    "Repeat recovery key password" : "복구 키 암호 확인",
    "Change recovery key password:" : "복구 키 암호 변경:",
    "Old recovery key password" : "이전 복구 키 암호",
    "New recovery key password" : "새 복구 키 암호",
    "Repeat new recovery key password" : "새 복구 키 암호 확인",
    "Change Password" : "암호 변경",
    "ownCloud basic encryption module" : "ownCloud 기본 암호화 모듈",
    "Your private key password no longer matches your log-in password." : "개인 키 암호와 로그인 암호가 일치하지 않습니다.",
    "Set your old private key password to your current log-in password:" : "기존 개인 키 암호를 로그인 암호와 동일하게 설정하십시오:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " 이전 암호가 기억나지 않으면 시스템 관리자에게 파일 복구를 요청하십시오.",
    "Old log-in password" : "이전 로그인 암호",
    "Current log-in password" : "현재 로그인 암호",
    "Update Private Key Password" : "개인 키 암호 업데이트",
    "Enable password recovery:" : "암호 복구 사용:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "이 옵션을 사용하면 암호를 잊었을 때 암호화된 파일에 다시 접근할 수 있습니다",
    "Enabled" : "활성화",
    "Disabled" : "비활성화"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/apps/encryption/l10n/ko.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "잊어버린 복구 키 암호 복구",
    "Please repeat the recovery key password" : "복구 키 암호를 다시 입력하십시오",
    "Repeated recovery key password does not match the provided recovery key password" : "입력한 복구 키 암호가 서로 다릅니다",
    "Recovery key successfully enabled" : "복구 키가 성공적으로 활성화되었습니다",
    "Could not enable recovery key. Please check your recovery key password!" : "복구 키를 활성화 할 수 없습니다. 복구 키의 암호를 확인해 주십시오!",
    "Recovery key successfully disabled" : "복구 키가 성공적으로 비활성화 되었습니다",
    "Could not disable recovery key. Please check your recovery key password!" : "복구 키를 비활성화 할 수 없습니다. 복구 키의 암호를 확인해 주십시오!",
    "Missing parameters" : "인자 부족함",
    "Please provide the old recovery password" : "이전 복구 암호를 입력하십시오",
    "Please provide a new recovery password" : "새 복구 암호를 입력하십시오",
    "Please repeat the new recovery password" : "새 복구 암호를 다시 입력하십시오",
    "Password successfully changed." : "암호가 성공적으로 변경되었습니다",
    "Could not change the password. Maybe the old password was not correct." : "암호를 변경할 수 없습니다. 예전 암호가 정확하지 않은 것 같습니다.",
    "Recovery Key disabled" : "복구 키가 비활성화됨",
    "Recovery Key enabled" : "복구 키가 활성화됨",
    "Could not enable the recovery key, please try again or contact your administrator" : "복구 키를 활성화할 수 없습니다. 다시 시도하거나 관리자에게 연락하십시오",
    "Could not update the private key password." : "개인 키 암호를 업데이트할 수 없습니다",
    "The old password was not correct, please try again." : "이전 암호가 잘못되었습니다. 다시 시도하십시오.",
    "The current log-in password was not correct, please try again." : "현재 로그인 암호가 잘못되었습니다. 다시 시도하십시오.",
    "Private key password successfully updated." : "개인 키 암호가 성공적으로 업데이트 되었습니다.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "과거에 사용하였던(ownCloud <= 8.0) 암호화된 데이터에서 키를 이전해야 합니다. 'occ encryption:migrate'를 실행하거나 시스템 관리자에게 연락하십시오",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "암호화 앱의 개인 키가 잘못되었습니다. 암호화된 파일에 다시 접근하려면 개인 설정에서 개인 키 암호를 업데이트해야 합니다.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "암호화 앱이 활성화되어 있지만 키가 초기화되지 않았습니다. 로그아웃한 후 다시 로그인하십시오",
    "Encryption App is enabled and ready" : "암호화 앱이 활성화되었고 준비됨",
    "one-time password for server-side-encryption" : "서버 측 암호화용 일회용 암호",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "이 파일을 복호화할 수 없습니다. 공유된 파일일 수도 있습니다. 파일 소유자에게 공유를 다시 요청하십시오.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "이 파일을 읽을 수 없습니다. 공유된 파일이라면 파일 소유자에게 연락하여 다시 공유해 달라고 요청하십시오.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'ownCloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "안녕하세요,\n\n시스템 관리자가 서버 측 암호화를 활성화했습니다. 저장된 파일이 암호 '%s'으(로) 암호화되었습니다.\n\n웹 인터페이스에 로그인하여 개인 설정의 'ownCloud 기본 암호화 모듈'로 이동한 다음, '이전 로그인 암호' 필드에 위 암호를 입력하고 현재 로그인 암호로 변경하여 암호화 암호를 업데이트하십시오.\n\n",
    "The share will expire on %s." : "이 공유는 %s 까지 유지됩니다.",
    "Cheers!" : "감사합니다!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"ownCloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "안녕하세요,<br><br>시스템 관리자가 서버 측 암호화를 활성화했습니다. 저장된 파일이 암호 <strong>%s</strong>으(로) 암호화되었습니다.<br><br>웹 인터페이스에 로그인하여 개인 설정의 'ownCloud 기본 암호화 모듈'로 이동한 다음, '이전 로그인 암호' 필드에 위 암호를 입력하고 현재 로그인 암호로 변경하여 암호화 암호를 업데이트하십시오.<br><br>",
    "Encrypt the home storage" : "홈 저장소 암호화",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "이 옵션을 사용하면 주 저장소에 있는 모드 파일을 암호화하며, 사용하지 않으면 외부 저장소의 파일만 암호화합니다",
    "Enable recovery key" : "복구 키 활성화",
    "Disable recovery key" : "복구 키 비활성화",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "복구 키는 파일을 암호화하는 추가 키입니다. 사용자가 암호를 잊었을 때 복구할 수 있도록 해 줍니다.",
    "Recovery key password" : "복구 키 암호",
    "Repeat recovery key password" : "복구 키 암호 확인",
    "Change recovery key password:" : "복구 키 암호 변경:",
    "Old recovery key password" : "이전 복구 키 암호",
    "New recovery key password" : "새 복구 키 암호",
    "Repeat new recovery key password" : "새 복구 키 암호 확인",
    "Change Password" : "암호 변경",
    "ownCloud basic encryption module" : "ownCloud 기본 암호화 모듈",
    "Your private key password no longer matches your log-in password." : "개인 키 암호와 로그인 암호가 일치하지 않습니다.",
    "Set your old private key password to your current log-in password:" : "기존 개인 키 암호를 로그인 암호와 동일하게 설정하십시오:",
    " If you don't remember your old password you can ask your administrator to recover your files." : " 이전 암호가 기억나지 않으면 시스템 관리자에게 파일 복구를 요청하십시오.",
    "Old log-in password" : "이전 로그인 암호",
    "Current log-in password" : "현재 로그인 암호",
    "Update Private Key Password" : "개인 키 암호 업데이트",
    "Enable password recovery:" : "암호 복구 사용:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "이 옵션을 사용하면 암호를 잊었을 때 암호화된 파일에 다시 접근할 수 있습니다",
    "Enabled" : "활성화",
    "Disabled" : "비활성화",
    "Bad Signature" : "잘못된 서명",
    "Missing Signature" : "서명 없음"
},
"nplurals=1; plural=0;");
